Module error

Module error 

error associated with dhatu

Enums

CallbackExecutorError
errors related with executing transaction http callback.
Error
the base error enum. this is the expected error type that will be returned.
FundsReserveError
reserve funds transaction error
KeypairGenerationError
all error that can happen when generating and parsing keypair related stuff.
MandalaClientErorr
error that happens on the underlying blockchain rpc client.
PasswordGenerationError
error related to keypair password generation.
SelectorError
error that can happen when parsing function selector.
ToPayloadError
errors that can happen when encoding calldata to pallet contrats payload.
TxBuilderError
errors that can happen when signing transaction.